
# Slot: positively regulates, process to process




URI: [biolink:positively_regulates_process_to_process](https://w3id.org/biolink/vocab/positively_regulates_process_to_process)

## Domain and Range

[Occurrent](Occurrent.md) ->  <sub>0..*</sub> [Occurrent](Occurrent.md)

## Parents

 *  is_a: [regulates, process to process](regulates_process_to_process.md)

## Children


## Used by

 * [Occurrent](Occurrent.md)
